@@ -21,12 +21,15 @@ DEVICE_INFO = "device"
 LIGHT = "light"
 SCHEDULE = "schedule"
 TIMER = "timer"
+SHADE = "shade"
+STATE = "state"
 
 # Special endpoints
 LOG = "/log"
 FIRMWARE = "/load"
 
 SETTINGS = "settings"
+SYSTEM_CONFIG = "system_config"
 FRONT_LED_GET = "led/get"
 FRONT_LED_SET = "led/set"
 BUTTON_ACTIONS = "action"
@@ -34,10 +37,16 @@ WIFI_SCAN = "scan"
 
 # Configuration endpoints
 PIR_CONFIGURATION = "pir_config"
+BLIND_CONFIGURATION = "blind_config"
 THERMOSTAT_CONFIGURATION = "thermostat_config"
 INPUT_CONFIGURATION = "input_config"
 
 # Communication constants
 CONTENT_TYPE_JSON = "application/json"
-CONTENT_TYPE = 'Content-Type'
+CONTENT_TYPE = "Content-Type"
 CONTENT_TYPE_TEXT_PLAIN = "text/plain"
+
+DEVICE_MAPPING = {
+    "102": "myStrom Bulb",
+    "108": "dingz",
+}
